@@ -1,16 +1,16 @@
-# ABSTRACT: A proper ODM (Object-Document-Mapper) for MongoDB
+# ABSTRACT: A proper ODM (Object-Document-Mapper) for MongoDB 
 
 use strict;
 use warnings;
 
 package MongoDBI;
 {
-    $MongoDBI::VERSION = '0.0.1_02';
+  $MongoDBI::VERSION = '0.0.2';
 }
 
 use 5.001000;
 
-our $VERSION = '0.0.1_02';    # VERSION
+our $VERSION = '0.0.2'; # VERSION
 
 use Moose ('extends');
 
@@ -19,7 +19,6 @@ extends 'MongoDBI::Application';
 
 1;
 __END__
-
 =pod
 
 =head1 NAME
@@ -28,7 +27,7 @@ MongoDBI - A proper ODM (Object-Document-Mapper) for MongoDB
 
 =head1 VERSION
 
-version 0.0.1_02
+version 0.0.2
 
 =head1 SYNOPSIS
 
@@ -60,7 +59,7 @@ version 0.0.1_02
     
     my $cddb = CDDB->new;
     
-    my $cds  = $cddb->class('Album'); # grabs CDDB::Album
+    my $cds  = $cddb->class('album'); # grabs CDDB::Album
     
     # find cds released during or after the year 2000
     my $year_2000 = DateTime->now->set(year => 2000, month => 1, day => 1);
@@ -89,9 +88,9 @@ automated indexing, moose-integration (inheritance support, etc), lean
 document updates via dirty field tracking, and ability for each class to be
 configured to use a different database and connection, etc.
 
-Note! This library is still in its infancy and subject to change. The POD
-(documentation) may also be lacking in certain areas, for additional insight
-you may examine the accompanying tests.
+Note! This library is still in its infancy and subject to change in code and
+in the overall design. The POD (documentation) may also be lacking in certain
+areas, for additional insight you may examine the accompanying tests.
 
 This class, MongoDBI, sub-classes L<MongoDBI::Application>, please review that
 module for more usage information.
