@@ -1,16 +1,16 @@
-# ABSTRACT: Base Class for a MongoDBI Document Class
+# Base Class for a MongoDBI Document Class
 
 use strict;
 use warnings;
 
 package MongoDBI::Document::Base;
 {
-    $MongoDBI::Document::Base::VERSION = '0.0.1_02';
+  $MongoDBI::Document::Base::VERSION = '0.0.2';
 }
 
 use 5.001000;
 
-our $VERSION = '0.0.1_02';    # VERSION
+our $VERSION = '0.0.2'; # VERSION
 
 use Moose ('with');
 use Moose::Exporter;
@@ -18,7 +18,10 @@ use MooseX::Traits;
 use MongoDBI::Document::Sugar ();
 
 my ($import, $unimport, $init_meta) = Moose::Exporter->build_import_methods(
-    also             => ['Moose', 'MongoDBI::Document::Sugar',],
+    also             => [
+        'Moose',
+        'MongoDBI::Document::Sugar',
+    ],
     base_class_roles => [
         'MongoDBI::Document::Storage',
         'MongoDBI::Document::Storage::Operation',
@@ -27,7 +30,7 @@ my ($import, $unimport, $init_meta) = Moose::Exporter->build_import_methods(
 
 sub init_meta {
     my ($dummy, %opts) = @_;
-
+    
     my $meta = Moose->init_meta(%opts);
     Moose::Util::MetaRole::apply_base_class_roles(
         for   => $opts{for_class},
@@ -37,65 +40,64 @@ sub init_meta {
             'MongoDBI::Document::Storage::Operation',
         ]
     );
-
+    
     # all document class instances should have an _dirty attribute
     # for tracking dirty columns as they are changed
     $meta->add_attribute(
         '_dirty' => (
-            is      => 'rw',
-            isa     => 'HashRef',
-            default => sub {
-                {
-
-                };
-            }
+            is => 'rw',
+            isa => 'HashRef',
+            default => sub {{
+                
+            }}
         )
     );
-
+    
     # all document class instances should have an _id field
     # as they represent documents in a collection
     $meta->add_attribute(
         '_id' => (
-            is  => 'rw',
+            is => 'rw',
             isa => 'MongoDB::OID'
         )
     );
-
+    
     # all document class instances should has a convenience
     # accessor for the special _id attr
     $meta->add_method(
         'id' => sub {
-            my $self = shift;
+            my $self = shift ;
             return $self->_id ? $self->_id->value : 0;
         }
     );
-
+    
     # all document class instances should be able to access
     # the special configuration attribute
     $meta->add_method(
         'config' => sub {
-            shift->_config;
+            shift->_config
         }
     );
-
+    
     # determine whether and/or which fields have been changed
     $meta->add_method(
         'changed' => sub {
             my ($self, $field) = @_;
-            return $field
-              ? scalar(defined $self->_dirty->{$field})
-              : scalar(values %{$self->_dirty});
+            return $field ?
+                scalar (defined $self->_dirty->{$field}) :
+                scalar (values %{ $self->_dirty }) ;
         }
     );
-
+    
     # determine whether if/how fields have been changed
     $meta->add_method(
         'change' => sub {
             my ($self, $field) = @_;
-            return $self->changed($field) ? $self->_dirty->{$field}->[-1] : 0;
+            return $self->changed($field) ?
+                $self->_dirty->{$field}->[-1] : 0 ;
         }
     );
-
+    
     return Class::MOP::class_of($opts{for_class});
 }
 
@@ -109,29 +111,4 @@ sub unimport {
     goto &$unimport;
 }
 
-1;
-__END__
-
-=pod
-
-=head1 NAME
-
-MongoDBI::Document::Base - Base Class for a MongoDBI Document Class
-
-=head1 VERSION
-
-version 0.0.1_02
-
-=head1 AUTHOR
-
-Al Newkirk <awncorp@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2011 by awncorp.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
+1;
\ No newline at end of file
